Class: XapiScraper::Articles
- Inherits:
-
Object
- Object
- XapiScraper::Articles
- Extended by:
- T::Sig
- Defined in:
- lib/xapi_scraper/articles.rb
Instance Method Summary collapse
- #fetch(request:, retries: nil, timeout_ms: nil, http_headers: nil) ⇒ Object
- #get_url(base_url:, url_variables: nil) ⇒ Object
-
#initialize(sdk_config) ⇒ Articles
constructor
A new instance of Articles.
- #markdown(request:, retries: nil, timeout_ms: nil, http_headers: nil) ⇒ Object
Constructor Details
#initialize(sdk_config) ⇒ Articles
Returns a new instance of Articles.
21 22 23 |
# File 'lib/xapi_scraper/articles.rb', line 21 def initialize(sdk_config) @sdk_configuration = sdk_config end |
Instance Method Details
#fetch(request:, retries: nil, timeout_ms: nil, http_headers: nil) ⇒ Object
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/xapi_scraper/articles.rb', line 49 def fetch(request:, retries: nil, timeout_ms: nil, http_headers: nil) # fetch - Batch Fetch X Articles # Retrieves detailed article content for a specified list of X (Twitter) IDs. Use this endpoint to fetch full text, metadata, and media links for multiple posts in a single request. The maximum input quantity is limited by your plan's QPS. To pass larger input quantity limits, upgrade your plan to get higher QPS. url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = "#{base_url}/x/article" headers = {} headers = T.cast(headers, T::Hash[String, String]) req_content_type, data, form = Utils.serialize_request_body(request, false, false, :request, :json) headers["content-type"] = req_content_type raise StandardError, "request body is required" if data.nil? && form.nil? if form && !form.empty? body = Utils.encode_form(form) elsif Utils.match_content_type(req_content_type, "application/x-www-form-urlencoded") body = URI.encode_www_form(T.cast(data, T::Hash[Symbol, Object])) else body = data end headers["Accept"] = "application/json" headers["user-agent"] = @sdk_configuration.user_agent retries ||= @sdk_configuration.retry_config retries ||= Utils::RetryConfig.new( backoff: Utils::BackoffStrategy.new( exponent: 1.5, initial_interval: 500, max_elapsed_time: 3_600_000, max_interval: 60_000 ), retry_connection_errors: true, strategy: "backoff" ) = retries.(initial_time: Time.now) [:retry_statuses] = [408, 409, 429, 500, 501, 502, 503, 504, 505] security = @sdk_configuration.security_source&.call timeout = (timeout_ms.to_f / 1000) unless timeout_ms.nil? timeout ||= @sdk_configuration.timeout connection = @sdk_configuration.client.dup connection.use(Utils::RetryMiddleware, ) hook_ctx = SDKHooks::HookContext.new( config: @sdk_configuration, base_url: base_url, oauth2_scopes: nil, operation_id: "articlesFetch", security_source: @sdk_configuration.security_source ) error = T.let(nil, T.nilable(StandardError)) http_response = T.let(nil, T.nilable(Faraday::Response)) begin http_response = T.must(connection).post(url) do |req| req.body = body req.headers.merge!(headers) req..timeout = timeout unless timeout.nil? Utils.configure_request_security(req, security) http_headers&.each do |key, value| req.headers[key.to_s] = value end @sdk_configuration.hooks.before_request( hook_ctx: SDKHooks::BeforeRequestHookContext.new( hook_ctx: hook_ctx ), request: req ) end rescue StandardError => e error = e ensure if http_response.nil? || Utils.error_status?(http_response.status) http_response = @sdk_configuration.hooks.after_error( error: error, hook_ctx: SDKHooks::AfterErrorHookContext.new( hook_ctx: hook_ctx ), response: http_response ) else http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) end if http_response.nil? raise error if !error.nil? raise "no response" end end content_type = http_response.headers.fetch("Content-Type", "application/octet-stream") if Utils.match_status_code(http_response.status, ["200"]) if Utils.match_content_type(content_type, "application/json") http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) response_data = http_response.env.response_body obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Components::XArticleResponse) response = Models::Operations::ArticlesFetchResponse.new( status_code: http_response.status, content_type: content_type, raw_response: http_response, x_article_response: T.unsafe(obj) ) return response else raise( ::XapiScraper::Models::Errors::APIError.new( status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response ), "Unknown content type received" ) end elsif Utils.match_status_code(http_response.status, ["422"]) if Utils.match_content_type(content_type, "application/json") http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) response_data = http_response.env.response_body obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Errors::HTTPValidationError) obj.raw_response = http_response raise obj else raise( ::XapiScraper::Models::Errors::APIError.new( status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response ), "Unknown content type received" ) end elsif Utils.match_status_code(http_response.status, ["4XX"]) raise( ::XapiScraper::Models::Errors::APIError.new( status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response ), "API error occurred" ) elsif Utils.match_status_code(http_response.status, ["5XX"]) raise( ::XapiScraper::Models::Errors::APIError.new( status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response ), "API error occurred" ) else raise( ::XapiScraper::Models::Errors::APIError.new( status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response ), "Unknown status code received" ) end end |
#get_url(base_url:, url_variables: nil) ⇒ Object
26 27 28 29 30 31 32 33 34 35 36 37 38 |
# File 'lib/xapi_scraper/articles.rb', line 26 def get_url(base_url:, url_variables: nil) sd_base_url, = @sdk_configuration.get_server_details if base_url.nil? base_url = sd_base_url end if url_variables.nil? url_variables = end return Utils.template_url(base_url, url_variables) end |
#markdown(request:, retries: nil, timeout_ms: nil, http_headers: nil) ⇒ Object
239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 |
# File 'lib/xapi_scraper/articles.rb', line 239 def markdown(request:, retries: nil, timeout_ms: nil, http_headers: nil) # markdown - Fetch Article as Markdown # Retrieves the content of an X (Twitter) article formatted as **clean, valid Markdown**. The response body is delivered as a raw UTF-8 string, optimized for direct import into static site generators, Obsidian, Notion, or any standard Markdown editor. url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = Utils.generate_url( Models::Operations::ArticlesMarkdownRequest, base_url, "/x/article/{tweet_id}/markdown", request ) headers = {} headers = T.cast(headers, T::Hash[String, String]) headers["Accept"] = "text/plain" headers["user-agent"] = @sdk_configuration.user_agent retries ||= @sdk_configuration.retry_config retries ||= Utils::RetryConfig.new( backoff: Utils::BackoffStrategy.new( exponent: 1.5, initial_interval: 500, max_elapsed_time: 3_600_000, max_interval: 60_000 ), retry_connection_errors: true, strategy: "backoff" ) = retries.(initial_time: Time.now) [:retry_statuses] = [408, 409, 429, 500, 501, 502, 503, 504, 505] security = @sdk_configuration.security_source&.call timeout = (timeout_ms.to_f / 1000) unless timeout_ms.nil? timeout ||= @sdk_configuration.timeout connection = @sdk_configuration.client.dup connection.use(Utils::RetryMiddleware, ) hook_ctx = SDKHooks::HookContext.new( config: @sdk_configuration, base_url: base_url, oauth2_scopes: nil, operation_id: "articlesMarkdown", security_source: @sdk_configuration.security_source ) error = T.let(nil, T.nilable(StandardError)) http_response = T.let(nil, T.nilable(Faraday::Response)) begin http_response = T.must(connection).get(url) do |req| req.headers.merge!(headers) req..timeout = timeout unless timeout.nil? Utils.configure_request_security(req, security) http_headers&.each do |key, value| req.headers[key.to_s] = value end @sdk_configuration.hooks.before_request( hook_ctx: SDKHooks::BeforeRequestHookContext.new( hook_ctx: hook_ctx ), request: req ) end rescue StandardError => e error = e ensure if http_response.nil? || Utils.error_status?(http_response.status) http_response = @sdk_configuration.hooks.after_error( error: error, hook_ctx: SDKHooks::AfterErrorHookContext.new( hook_ctx: hook_ctx ), response: http_response ) else http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) end if http_response.nil? raise error if !error.nil? raise "no response" end end content_type = http_response.headers.fetch("Content-Type", "application/octet-stream") if Utils.match_status_code(http_response.status, ["200"]) if Utils.match_content_type(content_type, "text/plain") http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) obj = http_response.env.body.force_encoding("UTF-8") return Models::Operations::ArticlesMarkdownResponse.new( status_code: http_response.status, content_type: content_type, raw_response: http_response, res: T.unsafe(obj) ) else raise( ::XapiScraper::Models::Errors::APIError.new( status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response ), "Unknown content type received" ) end elsif Utils.match_status_code(http_response.status, ["422"]) if Utils.match_content_type(content_type, "application/json") http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) response_data = http_response.env.response_body obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Errors::HTTPValidationError) obj.raw_response = http_response raise obj else raise( ::XapiScraper::Models::Errors::APIError.new( status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response ), "Unknown content type received" ) end elsif Utils.match_status_code(http_response.status, ["4XX"]) raise( ::XapiScraper::Models::Errors::APIError.new( status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response ), "API error occurred" ) elsif Utils.match_status_code(http_response.status, ["5XX"]) raise( ::XapiScraper::Models::Errors::APIError.new( status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response ), "API error occurred" ) else raise( ::XapiScraper::Models::Errors::APIError.new( status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response ), "Unknown status code received" ) end end |